Crate proto_pdk_test_utils

Crate proto_pdk_test_utils 

Modules

flow

Macros

anyhow
Construct an ad-hoc error from a string or existing non-anyhow error value.
api_enum
Wrap an enum with common derives and serde required attributes.
api_struct
Wrap a struct with common derives and serde required attributes.
api_unit_enum
Wrap a unit-only enum with common derives and serde required attributes.
check_install_success
create_plugin
do_build_from_source
do_install_prebuilt
generate_build_install_tests
generate_download_install_tests
generate_native_install_tests
generate_resolve_versions_tests
generate_shims_test

Structs

ActivateEnvironmentInput
Input passed to the activate_environment function.
ActivateEnvironmentOutput
Output returned by the activate_environment function.
ArchiveSource
Source code is contained in an archive.
BuildInstructionsInput
Input passed to the build_instructions function.
BuildInstructionsOutput
Output returned by the build_instructions function.
BuilderInstruction
A builder and its parameters for installing the builder.
Checksum
Represents a checksum for a specific algorithm.
CommandInstruction
A command and its parameters to be executed as a child process.
DataLocator
An inline data locator.
DefineBackendConfigOutput
Output returned from the define_backend_config function.
DefineToolConfigOutput
Output returned from the define_tool_config function.
DependencyConfig
Configuration for one or many system dependencies (packages).
DetectVersionInput
Input passed to the detect_version_files function.
DetectVersionOutput
Output returned by the detect_version_files function.
DownloadPrebuiltInput
Input passed to the download_prebuilt function.
DownloadPrebuiltOutput
Output returned by the download_prebuilt function.
EmptyInput
Represents an empty input.
ExecCommandInput
Input passed to the exec_command host function.
ExecCommandOutput
Output returned from the exec_command host function.
ExecutableConfig
Configuration for generated shim and symlinked executable files.
FileLocator
A file system locator.
FormatOptions
Options for formatting a version into a string.
GitHubLocator
A GitHub release locator.
GitSource
Source code is located in a Git repository.
HostEnvironment
Information about the host environment (the current runtime).
HostLogInput
Input passed to the host_log host function.
Id
A compact string identifier for use within records, key lookups, and more. Supports unicode alphanumeric characters, forward slash /, period ., underscore _, and dash -. A leading @ is supported to support npm package names.
IdError
ID errors.
InstallHook
Input passed to the pre_install and post_install hooks, while a proto install command is running.
LoadVersionsInput
Input passed to the load_versions function.
LoadVersionsOutput
Output returned by the load_versions function.
LocateExecutablesInput
Input passed to the locate_executables function.
LocateExecutablesOutput
Output returned by the locate_executables function.
MessageOutput
NativeInstallInput
Input passed to the native_install function.
NativeInstallOutput
Output returned by the native_install function.
NativeUninstallInput
Input passed to the native_uninstall function.
NativeUninstallOutput
Output returned by the native_uninstall function.
NoticeOutput
ParseVersionFileInput
Input passed to the parse_version_file function.
ParseVersionFileOutput
Output returned by the parse_version_file function.
PinVersionInput
Input passed to the pin_version function.
PinVersionOutput
Output returned by the pin_version function.
PluginContext
Information about the current state of the plugin, after a version has been resolved.
PluginUnresolvedContext
Information about the current state of the plugin, before a version has been resolved.
ProgressOutput
ProtoConfig
ProtoEnvironment
ProtoReporter
ProtoWasmSandbox
Range
A version range composed of clauses, in which any clause may match, for example ^1 || 2.3.4 - 3.0.0 || >=4, <5.
RegisterBackendInput
Input passed to the register_backend function.
RegisterBackendOutput
Output returned by the register_backend function.
RegisterToolInput
Input passed to the register_tool function.
RegisterToolOutput
Output returned by the register_tool function.
RegistryLocator
An OCI registry locator.
Requirement
A version requirement composed of a comparison operator and a full or partial version to match against. Build metadata is accepted when parsing, but is otherwise ignored.
ResolveVersionInput
Input passed to the resolve_version function.
ResolveVersionOutput
Output returned by the resolve_version function.
RunHook
Input passed to the pre_run hook, before a proto run command or language executable is ran.
RunHookResult
Output returned from the pre_run hook.
SendRequestInput
Input passed to the send_request host function.
SendRequestOutput
Output returned from the send_request host function.
SyncManifestInput
Input passed to the sync_manifest function.
SyncManifestOutput
Output returned by the sync_manifest function.
SyncShellProfileInput
Input passed to the sync_shell_profile function.
SyncShellProfileOutput
Output returned by the sync_shell_profile function.
SyntaxParser
TableOutput
TestEnvironment
Information about the current testing environment.
Tool
ToolContext
ToolInventoryOptions
Controls aspects of the tool inventory.
ToolLockOptions
Options related to lockfile integration.
ToolManifest
ToolSpec
UnpackArchiveInput
Input passed to the unpack_archive function.
UnpinVersionInput
Input passed to the unpin_version function.
UnpinVersionOutput
Output returned by the unpin_version function.
UrlLocator
A HTTPS URL locator.
VerifyChecksumInput
Output returned by the verify_checksum function.
VerifyChecksumOutput
Output returned by the verify_checksum function.
Version
A version in either calendar or semantic format, with support for scopes, pre-releases, and build metadata.
WasmTestWrapper

Enums

BuildInstruction
An instruction to execute.
BuildRequirement
Is required and must exist in the current environment.
ChecksumAlgorithm
Supported checksum algorithms.
ChecksumError
Errors that may occur from within a plugin.
Clause
A single clause within a version range.
Data
DependencyName
A system dependency name in multiple formats.
Event
HookFunction
Enumeration of all available hook functions that can be implemented by plugins.
HostArch
Architecture of the system environment.
HostLibc
Libc being used in the system environment.
HostLogTarget
Target where host logs should be written to.
HostOS
Operating system of the current environment.
HostPackageManager
Package manager of the system environment.
InstallStrategy
Supported strategies for installing a tool.
Op
The comparison operator of a requirement.
PluginError
Errors that may occur from within a plugin.
PluginFunction
Enumeration of all available plugin functions that can be implemented by plugins.
PluginLocator
Strategies and protocols for locating plugins.
PluginLocatorError
Errors during plugin locator parsing.
PluginType
Supported types of plugins.
ReporterFormat
Rule
SourceLocation
The location in which source code can be acquired.
SpecError
StringOrVec
Either a string, or a list of strings.
Switch
Either a boolean representing on or off, or a string representing on with a message.
SystemDependency
Represents a system dependency (one or many packages) to install.
UnresolvedVersionSpec
Represents an unresolved version or alias that must be resolved to a fully-qualified version.
VersionKind
The kind of version, either calendar or semantic.
VersionSpec
Represents a resolved version or alias.
VirtualPath
A container for WASI virtual paths that can also keep a reference to the original real path.
Wasm
The Wasm type specifies how to access a WebAssembly module

Statics

ID_CLEAN_PATTERN
Pattern that removes unsupported characters from an identifier.
ID_PATTERN
Pattern that all identifiers are matched against. Supports unicode alphanumeric characters, forward slash /, period ., underscore _, and dash -. A leading @ is supported to support npm package names.

Traits

FormatsVersion
Trait for formatting a version into a string with custom options.
MatchesVersion
Trait for matching a version against the implementing type.
ProtoConfigBuilder

Functions

create_empty_proto_sandbox
create_proto_sandbox
is_calver_like
Returns true if the provided value looks like a calendar version string, instead of a semantic version string. This is used to determine which parser to use.
is_semver_like
Returns true if the provided value looks like a semver version string, instead of a calendar version string. This is used to determine which parser to use.

Type Aliases

AnyResult
Represents any result (using anyhow).
ConfigSchema
ParseError
ProtoConsole
ToolMetadataInputDeprecated
ToolMetadataOutputDeprecated